"""Type stubs for neologdn."""

def normalize(text: str, repeat: int = 0) -> str:
    """Normalize Japanese text.

    Args:
        text: Text to normalize.
        repeat: Maximum number of repeated characters to allow (0 = unlimited).

    Returns:
        Normalized text.
    """
    ...
